@@ -53,10 +53,10 @@ from maphis.tags_widget import TagsPopupPanel, PhotoTagsPopupPanel
 from maphis.thumbnail_gui import ThumbGUI
 from maphis.thumbnail_storage import ThumbnailStorage_
 from maphis.tools.ruler import Tool_Ruler
-from common.popup_widget import PopupLocation
-from plugin_manager.plugin_store import PluginStore
-from tags.tag_chooser import TagsChooser
-from ui_maphis import Ui_MAPHIS
+from maphis.common.popup_widget import PopupLocation
+from maphis.plugin_manager.plugin_store import PluginStore
+from maphis.tags.tag_chooser import TagsChooser
+from maphis.ui_maphis import Ui_MAPHIS
 
 
 logging.basicConfig(filename='maphis.log', level=logging.INFO, format="%(asctime)s %(filename)-30s %(levelname)-8s %(message)s")
@@ -335,7 +335,7 @@ class MAPHIS(QMainWindow):
 
         self.ui.tabLabelEditor.setLayout(hbox)
 
-        with importlib.resources.path('resources', 'undo.png') as path:
+        with importlib.resources.path('maphis.resources', 'undo.png') as path:
             undo_icon = QIcon(str(path))
             redo_pix = QImage(str(path))
             redo_pix = QPixmap.fromImage(redo_pix.mirrored(True, False))
@@ -657,7 +657,7 @@ class MAPHIS(QMainWindow):
         logger.info('Attempting to load tools')
         py_files = [inspect.getmodulename(file.path) for file in os.scandir(Path(__file__).parent / 'tools') if file.name.endswith('.py') and file.name != '__init__.py']
         logger.info(py_files)
-        modules = [importlib.import_module(f'.{module_name}', '.tools') for module_name in py_files]
+        modules = [importlib.import_module(f'.{module_name}', 'maphis.tools') for module_name in py_files]
         tools = []
         for module in modules:
             members = inspect.getmembers(module)
@@ -1367,9 +1367,9 @@ class MAPHIS(QMainWindow):
         # self.ui.tabWidget.setTabText(0, "Label editor")
 
 
-if __name__ == "__main__":
-    app = QApplication([])
-    window = MAPHIS()
-    app.focusChanged.connect(window.handle_focus_changed)
-    QTimer.singleShot(100, window.showMaximized)
-    sys.exit(app.exec())
+# if __name__ == "__main__":
+#     app = QApplication([])
+#     window = MAPHIS()
+#     app.focusChanged.connect(window.handle_focus_changed)
+#     QTimer.singleShot(100, window.showMaximized)
+#     sys.exit(app.exec())
