@@ -9,13 +9,14 @@ from pathlib import Path
 import PySide6
 import cv2
 import numpy as np
-import qimage2ndarray
+
 from PySide6 import QtGui, QtCore
 from PySide6.QtCore import Qt, Signal, QPoint, QObject, QRect
 from PySide6.QtGui import QImage, QPixmap
 from PySide6.QtWidgets import QWidget, QHBoxLayout, QLabel, QSpinBox, QPushButton, QComboBox, QDoubleSpinBox, QDialog, \
     QDialogButtonBox, QVBoxLayout, QStyleOptionViewItem, QGroupBox
 
+from maphis import qimage2ndarray
 from maphis.common.blocking_operation import BlockingOperation
 from maphis.common.image_operation_binding import ImageOperation
 from maphis.common.photo import Photo, UpdateContext, UpdateEvent, PhotoUpdate, PhotoUpdateType
